@@ -1,16 +1,16 @@
 # flake8: noqa
-import pkgutil
+from importlib import util as importlib_util
 
 from .filters import *
 from .filterset import FilterSet
 
 # We make the `rest_framework` module available without an additional import.
 #   If DRF is not installed, no-op.
-if pkgutil.find_loader("rest_framework") is not None:
+if importlib_util.find_spec("rest_framework"):
     from . import rest_framework
-del pkgutil
+del importlib_util
 
-__version__ = "23.1"
+__version__ = "23.5"
 
 
 def parse_version(version):
@@ -29,3 +29,11 @@ def parse_version(version):
 
 
 VERSION = parse_version(__version__)
+
+
+
+assert VERSION < (25,0), "Remove deprecated code"
+
+
+class RemovedInDjangoFilter25Warning(DeprecationWarning):
+    pass
