@@ -1,13 +1,12 @@
-
 from django.db import models
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 
 class BasicModel(models.Model):
     text = models.CharField(
         max_length=100,
         verbose_name=_("Text comes here"),
-        help_text=_("Text description.")
+        help_text=_("Text description."),
     )
 
 
@@ -25,4 +24,10 @@ class DjangoFilterOrderingModel(models.Model):
     text = models.CharField(max_length=10)
 
     class Meta:
-        ordering = ['-date']
+        ordering = ["-date"]
+
+
+class CategoryItem(BaseFilterableItem):
+    category = models.CharField(
+        max_length=10, choices=(("home", "Home"), ("office", "Office"))
+    )
